netapp_ontap.models.fpolicy_policy_scope API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.fpolicy_policy_scope`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FpolicyPolicyScopeSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FpolicyPolicyScope object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `exclude_export_policies GET POST PATCH`

    The exclude_export_policies field of the fpolicy_policy_scope.

  `exclude_extension GET POST PATCH`

    The exclude_extension field of the fpolicy_policy_scope.

  `exclude_shares GET POST PATCH`

    The exclude_shares field of the fpolicy_policy_scope.

  `exclude_volumes GET POST PATCH`

    The exclude_volumes field of the fpolicy_policy_scope.

    Example: ["vol1","vol_svm1","*"]

  `include_export_policies GET POST PATCH`

    The include_export_policies field of the fpolicy_policy_scope.

  `include_extension GET POST PATCH`

    The include_extension field of the fpolicy_policy_scope.

  `include_shares GET POST PATCH`

    The include_shares field of the fpolicy_policy_scope.

    Example: ["sh1","share_cifs"]

  `include_volumes GET POST PATCH`

    The include_volumes field of the fpolicy_policy_scope.

    Example: ["vol1","vol_svm1"]